Module streams

Module streams 

Modules

guard

Macros

stream
Instrument a stream to track its item yields.

Structs

LogEntry
A single log entry for a message sent or received.
SerializableStreamStats
Serializable version of stream statistics for JSON responses.
StreamLogs
Serializable log response containing yielded logs for streams.
StreamsGuard
Guard for stream statistics collection. When dropped, prints a summary of all instrumented streams and their statistics.
StreamsGuardBuilder
Builder for creating a StreamsGuard with custom configuration.
StreamsJson
Wrapper for streams-only JSON response

Enums

ChannelState
State of a instrumented channel.
Format
Format of the output produced by ChannelsGuard on drop.

Functions

get_stream_logs
get_streams_json