Modules
Macros
- stream
- Instrument a stream to track its item yields.
Structs
- LogEntry
- A single log entry for a message sent or received.
- Serializable
Stream Stats - Serializable version of stream statistics for JSON responses.
- Stream
Logs - Serializable log response containing yielded logs for streams.
- Streams
Guard - Guard for stream statistics collection. When dropped, prints a summary of all instrumented streams and their statistics.
- Streams
Guard Builder - Builder for creating a StreamsGuard with custom configuration.
- Streams
Json - Wrapper for streams-only JSON response
Enums
- Channel
State - State of a instrumented channel.
- Format
- Format of the output produced by ChannelsGuard on drop.